@@ -1,12 +1,10 @@
 #include "ContactsParserObject.h"
-
-#include "Singletons.h"
 #include "ContactsXmlHandler.h"
-#include "ContactsModel.h"
 
 ContactsParserObject::ContactsParserObject (QByteArray data, QObject *parent)
 : QObject(parent)
 , byData (data)
+, bEmitLog (true)
 {
 }//ContactsParserObject::ContactsParserObject
 
@@ -16,6 +14,7 @@ ContactsParserObject::doWork ()
     QXmlInputSource inputSource;
     QXmlSimpleReader simpleReader;
     ContactsXmlHandler contactsHandler;
+    contactsHandler.setEmitLog (bEmitLog);
 
     inputSource.setData (byData);
 
@@ -31,10 +30,22 @@ ContactsParserObject::doWork ()
 
     bool rv = simpleReader.parse (&inputSource, false);
 
+    if (!rv) {
+        qDebug() << "Contacts parser failed to parse. Data =" << byData;
+    }
+
     QString msg = QString("Total contacts: %1. Usable: %2")
             .arg (contactsHandler.getTotalContacts ())
             .arg (contactsHandler.getUsableContacts ());
-    emit status(msg);
+    if (bEmitLog || (contactsHandler.getUsableContacts () != 0)) {
+        emit status(msg);
+    }
 
     emit done(rv);
 }//ContactsParserObject::doWork
+
+void
+ContactsParserObject::setEmitLog (bool enable /*= true*/)
+{
+    bEmitLog = enable;
+}//ContactsParserObject::setEmitLog
